searchData={"content_type":"text/markdown","items":[{"doc":"SimpleAgent is a simplification/abstraction layer around the base Elixir `Agent` module.\n\nOften times, Agents are used to store a simple value, such as an atom or an integer. This is used as a flag\nor a count which multiple processes can access/update. In these cases, the full `Agent` module is used with\nboilerplate closure code that is repetative, adds noise to the code, and can be eliminated. For example,\nto create an agent, update the value, then retrieve that value, you would run:\n\n    {:ok, agent} = Agent.start_link(fn -> nil end)\n    Agent.update(agent, fn _ -> :final_value end)\n    final_value = Agent.get(agent, fn val -> val end)\n\n`SimpleAgent` boils these calls down to a more readable:\n\n    agent = SimpleAgent.start!\n    SimpleAgent.update! agent, :final_value\n    completed = SimpleAgent.get! agent\n\nFor Integer manipulation, `SimpleAgent` takes this code:\n\n    {:ok, agent} = Agent.start_link(fn -> 0 end)\n    IO.puts Agent.get_and_update(fn val -> {val + 1, val + 1} end)\n    IO.puts Agent.get_and_update(fn val -> {val - 1, val - 1} end)\n    IO.puts Agent.get_and_update(fn val -> {val + 1, val + 1} end)\n    IO.puts Agent.get_and_update(fn val -> {val + 1, val + 1} end)\n\nand boils it down to the more readable:\n\n    agent = SimpleAgent.start! 0\n    IO.puts SimpleAgent.increment! agent\n    IO.puts SimpleAgent.decrement! agent\n    IO.puts SimpleAgent.increment! agent\n    IO.puts SimpleAgent.increment! agent\n\n`SimpleAgent` is very useful in testing. For example:\n\n    test \"foo calls bar 3 times\" do\n      bar_call_agent = SimpleAgent.start! 0\n      :meck.new(Bar)\n      :meck.expect(Bar, :bar, fn -> SimpleAgent.increment!(bar_call_agent) end)\n      Foo.foo()\n      assert SimpleAgent.get?(bar_call_agent) == 3\n    end\n\nWhy only simple types?\n\nWhen a complex state such as a map or a dict is in use, the correct way to manipulate the complex state is in\nthe Agent server via a closure. This prevents the entire state from being copied from the Agent Server to the\nClient (see the Agent docs for more information on this). For states with these complex types, you should use\nthe full `Agent` module. `SimpleAgent` is for those cases where the \"entire state\" is a single simple Integer,\nString, or Atom (including nil, true, and false).\n\nFeatures:\n\n* Simple types and updates reduce chances of errors, so all calls raise exceptions instead of requiring boilerplate\n  pattern matching, and `start!/2` is available instead of start_link\n* No closures are required.\n    * `get!/1` uses &(&1)\n    * `update!/2` takes the value instead of a function and uses fn _ -> value end\n* nil support\n    * `start!/2` defaults the initial value to nil when not specified\n    * `nil?/1` checks for the nil state\n    * `clear/1` sets the nil state\n* `increment!/2` and `decrement!/2` allow for simple manipulation of integer states.","ref":"SimpleAgent.html","title":"SimpleAgent","type":"module"},{"doc":"Resets the current state to nil","ref":"SimpleAgent.html#clear/1","title":"SimpleAgent.clear/1","type":"function"},{"doc":"Decreases the value of the current state by count (default 1). Raises error if current state is not an integer","ref":"SimpleAgent.html#decrement!/2","title":"SimpleAgent.decrement!/2","type":"function"},{"doc":"Returns true or false if the current state of the specified agent is the specified value","ref":"SimpleAgent.html#equals?/2","title":"SimpleAgent.equals?/2","type":"function"},{"doc":"Returns the current state of the agent. If the agent has an invalid type, raises an exception","ref":"SimpleAgent.html#get!/1","title":"SimpleAgent.get!/1","type":"function"},{"doc":"Increases the value of the current state by count (default 1). Raises error if current state is not an integer","ref":"SimpleAgent.html#increment!/2","title":"SimpleAgent.increment!/2","type":"function"},{"doc":"Returns true or false if the current state is nil","ref":"SimpleAgent.html#nil?/1","title":"SimpleAgent.nil?/1","type":"function"},{"doc":"Starts an agent with the specified initial value, or nil by default. Second optional parameter is\nthe standard GenServer options list.","ref":"SimpleAgent.html#start!/2","title":"SimpleAgent.start!/2","type":"function"},{"doc":"Returns the pid of the server to be used in subsequent calls to other `SimpleAgent` functions.","ref":"SimpleAgent.html#start!/2-return-values","title":"Return values - SimpleAgent.start!/2","type":"function"},{"doc":"Updates the state to the new value. Returns the new value.","ref":"SimpleAgent.html#update!/2","title":"SimpleAgent.update!/2","type":"function"},{"doc":"","ref":"SimpleAgent.html#t:agent/0","title":"SimpleAgent.agent/0","type":"type"},{"doc":"","ref":"SimpleAgent.html#t:valid_types/0","title":"SimpleAgent.valid_types/0","type":"type"}]}